make_email_payload: Constructs email payload from emails, subject and body

Description Usage Arguments Value See Also

View source: R/sendgrid.R

Description

Once the payload is constructed, you can use sendgrid_send to send the message

Usage

1
make_email_payload(to, subject, body, from, reply_to = from)

Arguments

to

email_group

subject

character vector with subject of message

body

character vector with body of message

from

email_person

reply_to

email_person

Value

list with payload in the format required by sendgrid_send

See Also

Other email functions: email_person, sendgrid_send


andrie/sendgridR documentation built on May 6, 2019, 2:19 p.m.