Description Usage Arguments Value See Also
Once the payload is constructed, you can use sendgrid_send to send the message
1 | make_email_payload(to, subject, body, from, reply_to = from)
|
to |
email_group |
subject |
character vector with subject of message |
body |
character vector with body of message |
from |
email_person |
reply_to |
email_person |
list with payload in the format required by sendgrid_send
Other email functions: email_person,
sendgrid_send
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.